@@ -1,7 +1,11 @@
 # Copyright 2009-2011 Ram Rachum.
 # This program is distributed under the LGPL2.1 license.
 
-'''A module for simulating Conway's Game of Life.'''
+'''
+This module defines the `State` class.
+
+See its documentation for more information.
+'''
 
 import random
 import itertools
@@ -10,6 +14,7 @@ import garlicsim.data_structures
 
 
 class State(garlicsim.data_structures.State):
+    '''World state. A frozen moment in time in the simulation world.'''
 
     @staticmethod
     def create_diehard(width=45, height=25):
@@ -30,6 +35,11 @@ class State(garlicsim.data_structures.State):
     
     @staticmethod
     def create_root(width=45, height=25, fill='empty'):
+        '''
+        Create a plain and featureless world state.
+        
+        `fill` may be either 'empty', 'full', or 'random'.
+        '''
         state = State()
         state.board = Board(width, height, fill)
         return state
@@ -37,11 +47,24 @@ class State(garlicsim.data_structures.State):
     
     @staticmethod
     def create_messy_root(width=45, height=25):
+        '''Create a state with a random board.'''
         return State.create_root(width, height, fill='random')
     
 
     def step_generator(self, birth=[3], survival=[2, 3], randomness=0):
-        # This isn't really more efficient than regular step; This is just a
+        '''
+        Perform a simulation step by yielding the next state every time.
+        
+        `birth` is the list of numbers of live neighbors that a dead cell
+        should have in order to become alive. `survival` is a list of the
+        numbers of live neighbors that a living cell should have in order to
+        stay alive. `randomness` is a float between 0 and 1, and is the amount
+        of randomness that should come into the board, e.g. a randomness of
+        `0.1` would introduce a random cell once in approximately 10 cells.
+        `randomness` may also be given as `False` or `True` for `0` or `1`
+        respectively.
+        '''
+        # This isn't really more efficient than regular step; this is just a
         # demonstration that `garlicsim` can handle step generators.
         current_state = self
         while True:
@@ -49,15 +72,28 @@ class State(garlicsim.data_structures.State):
             if current_state.get_n_live_cells() < \
                (current_state.board.width * \
                 current_state.board.height) / 10.:
-                
                 raise garlicsim.misc.WorldEnded
             
             current_state = current_state.step(birth=birth, survival=survival,
                                                randomness=randomness)
+            
+            
             yield current_state
     
     
     def step(self, birth=[3], survival=[2, 3], randomness=0, *args, **kwargs):
+        '''
+        Return the next state in time.
+        
+        `birth` is the list of numbers of live neighbors that a dead cell
+        should have in order to become alive. `survival` is a list of the
+        numbers of live neighbors that a living cell should have in order to
+        stay alive. `randomness` is a float between 0 and 1, and is the amount
+        of randomness that should come into the board, e.g. a randomness of
+        `0.1` would introduce a random cell once in approximately 10 cells.
+        `randomness` may also be given as `False` or `True` for `0` or `1`
+        respectively.
+        '''
         old_board = self.board
         new_board = Board(parent=old_board,
                           birth=birth,
@@ -98,10 +134,13 @@ class State(garlicsim.data_structures.State):
 
 
 class Board(object):
-    '''Represents a Life board.''' 
+    '''A Life board of cells which may be either dead or alive.''' 
+    
     def __init__(self, width=None, height=None, fill='empty', parent=None,
                  birth=[3], survival=[2, 3], randomness=0):
         '''
+        Constructor.
+        
         If `parent` is specified, makes a board which is descendent from the
         parent.
         '''
@@ -135,27 +174,22 @@ class Board(object):
         self.__list = []
         for i in xrange(self.width*self.height):
             self.__list.append(make_cell())
-
-    @staticmethod
-    def create_diehard(width=45, height=25):
-        board = Board(width, height)
-        (x, y) = (width//2, height//2)
-        for (i, j) in [(6, 0), (0, 1), (1, 1), (1, 2), (5, 2), (6, 2), (7, 2)]:
-            board.set(x + i, y + j, True)
-            
-        return board
         
     
     def get(self, x, y):
-        '''Get the value of cell (x, y) in the board.'''
+        '''Get the value of cell `(x, y)` in the board.'''
         return self.__list[ (x % self.width) * self.height + (y%self.height) ]
 
+    
     def set(self, x, y, value):
-        '''Set the value of cell (x, y) in the board to the specified value.'''
+        '''
+        Set the value of cell `(x, y)` in the board to the specified value.
+        '''
         self.__list[ (x%self.width) * self.height + (y%self.height) ] = value
 
-    def get_true_neighbors_count(self, x, y):
-        '''Get the number of True neighbors a cell has.'''
+        
+    def get_live_neighbors_count(self, x, y):
+        '''Get the number of live neighbors a cell has.'''
         result = 0
         for i in [-1 ,0 ,1]:
             for j in [-1, 0 ,1]:
@@ -165,16 +199,14 @@ class Board(object):
                     result += 1
         return result
 
+    
     def cell_will_become(self, x, y, birth=[3], survival=[2, 3],
                          randomness=0):
-        '''
-        Return what value a specified cell will have after an iteration of the
-        simulation.
-        '''
+        '''Get the value that cell `(x, y)` will have in the next turn.'''
         if randomness:
             if random.random() <= randomness:
                 return random.choice([True, False])
-        n = self.get_true_neighbors_count(x, y)
+        n = self.get_live_neighbors_count(x, y)
         if self.get(x, y) is True:
             if n in survival:
                 return True
@@ -186,29 +218,49 @@ class Board(object):
             else:
                 return False
 
+            
     def __repr__(self):
         '''Display the board, ASCII-art style.'''
         cell = lambda x, y: "#" if self.get(x, y) is True else " "
         row = lambda y: "".join(cell(x, y) for x in xrange(self.width))
         return "\n".join(row(y) for y in xrange(self.height))
+
     
     def __eq__(self, other):
         return isinstance(other, Board) and self.__list == other.__list
     
+    
     def __ne__(self, other):
         return not self.__eq__(other)
+    
+            
+    @staticmethod
+    def create_diehard(width=45, height=25):
+        '''
+        Create the Diehard Metushelah.
+        
+        It looks like this:
+        
+                   #
+             ##
+              #   ###
+
+        '''
+        board = Board(width, height)
+        (x, y) = (width//2, height//2)
+        for (i, j) in [(6, 0), (0, 1), (1, 1), (1, 2), (5, 2), (6, 2), (7, 2)]:
+            board.set(x + i, y + j, True)
+            
+        return board
 
 
 
 def determinism_function(step_profile):
-    try:
-        if step_profile.args[1] is True or \
-           step_profile.kwargs['krazy'] is True:
-            return garlicsim.misc.settings_constants.UNDETERMINISTIC
-    except LookupError:
-        pass
-    
-    return garlicsim.misc.settings_constants.DETERMINISTIC
+    '''Get determinism class of `step_profile`.'''
+    if step_profile['randomness']:
+        return garlicsim.misc.settings_constants.UNDETERMINISTIC
+    else:
+        return garlicsim.misc.settings_constants.DETERMINISTIC
 
 
    
@@ -231,4 +283,4 @@ def changes(history_browser):
         if board._Board__list[i] != last_board._Board__list[i]:
             counter += 1
     return counter
-"""
+"""
\ No newline at end of file
